@@ -11,8 +11,8 @@ from flask_cors import CORS
 from typing import Dict, Any  # noqa: F401
 from flasgger import Swagger
 
-from search_service.api.dashboard import SearchDashboardAPI
-from search_service.api.table import SearchTableAPI, SearchTableFieldAPI, SearchTableFilterAPI
+from search_service.api.dashboard import SearchDashboardAPI, SearchDashboardFilterAPI
+from search_service.api.table import SearchTableAPI, SearchTableFilterAPI
 from search_service.api.user import SearchUserAPI
 from search_service.api.document import DocumentUserAPI, DocumentTableAPI, DocumentTablesAPI, DocumentUsersAPI
 from search_service.api.healthcheck import healthcheck
@@ -81,19 +81,20 @@ def create_app(*, config_module_class: str) -> Flask:
     api_bp.add_url_rule('/healthcheck', 'healthcheck', healthcheck)
     api = Api(api_bp)
     # Table Search API
-    # TODO: Rename endpoint to be more generic and accept a resource type so that logic can be re-used
+
     api.add_resource(SearchTableFilterAPI, '/search_table')
+    # TODO: Rename endpoint to be more generic and accept a resource type so that logic can be re-used
     api.add_resource(SearchTableAPI, '/search')
-    api.add_resource(SearchTableFieldAPI,
-                     '/search/field/<field_name>/field_val/<field_value>')
 
     # User Search API
     api.add_resource(SearchUserAPI, '/search_user')
 
     # Dashboard Search API
     api.add_resource(SearchDashboardAPI, '/search_dashboard')
+    api.add_resource(SearchDashboardFilterAPI, '/search_dashboard_filter')
 
     # DocumentAPI
+    # todo: needs to update to handle dashboard/user or other entities use cases.
     api.add_resource(DocumentTablesAPI, '/document_table')
     api.add_resource(DocumentTableAPI, '/document_table/<document_id>')
 
