@@ -2,10 +2,12 @@ import logging
 from http import HTTPStatus
 from typing import Iterable, Any
 
-from flask_restful import fields, Resource, marshal_with, reqparse  # noqa: I201
 from flasgger import swag_from
+from flask_restful import Resource, reqparse  # noqa: I201
 
+from search_service.api.base import BaseFilterAPI
 from search_service.exception import NotFoundException
+from search_service.models.dashboard import SearchDashboardResultSchema
 from search_service.proxy import get_proxy_client
 
 
@@ -13,24 +15,6 @@ DASHBOARD_INDEX = 'dashboard_search_index'
 
 LOGGING = logging.getLogger(__name__)
 
-# todo: Use common to produce this
-dashboard_fields = {
-    "uri": fields.String,
-    "cluster": fields.String,
-    "group_name": fields.String,
-    "group_url": fields.String,
-    "product": fields.String,
-    "name": fields.String,
-    "url": fields.String,
-    "description": fields.String,
-    "last_successful_run_timestamp": fields.Integer
-}
-
-search_dashboard_results = {
-    "total_results": fields.Integer,
-    "results": fields.Nested(dashboard_fields, default=[])
-}
-
 
 class SearchDashboardAPI(Resource):
     """
@@ -48,7 +32,6 @@ class SearchDashboardAPI(Resource):
 
         super(SearchDashboardAPI, self).__init__()
 
-    @marshal_with(search_dashboard_results)
     @swag_from('swagger_doc/dashboard/search_dashboard.yml')
     def get(self) -> Iterable[Any]:
         """
@@ -65,7 +48,7 @@ class SearchDashboardAPI(Resource):
                 index=args['index']
             )
 
-            return results, HTTPStatus.OK
+            return SearchDashboardResultSchema().dump(results).data, HTTPStatus.OK
 
         except NotFoundException:
             return {'message': 'query_term does not exist'}, HTTPStatus.NOT_FOUND
@@ -75,3 +58,20 @@ class SearchDashboardAPI(Resource):
             err_msg = 'Exception encountered while processing search request'
             LOGGING.exception(err_msg)
             return {'message': err_msg}, HTTPStatus.INTERNAL_SERVER_ERROR
+
+
+class SearchDashboardFilterAPI(BaseFilterAPI):
+    """
+    Search Filter for Dashboard
+    """
+    def __init__(self) -> None:
+        super().__init__(schema=SearchDashboardResultSchema,
+                         index=DASHBOARD_INDEX)
+
+    @swag_from('swagger_doc/dashboard/search_dashboard_filter.yml')
+    def post(self) -> Iterable[Any]:
+        try:
+            return super().post()
+        except RuntimeError:
+            err_msg = 'Exception encountered while processing search request'
+            return {'message': err_msg}, HTTPStatus.INTERNAL_SERVER_ERROR
