@@ -1,6 +1,8 @@
 from abc import ABCMeta, abstractmethod
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
+from search_service.models.dashboard import SearchDashboardResult
+from search_service.models.table import SearchTableResult
 from search_service.models.search_result import SearchResult
 
 
@@ -10,20 +12,11 @@ class BaseProxy(metaclass=ABCMeta):
     the proxy clients available in the amundsen search service
     """
 
-    @abstractmethod
-    def fetch_table_search_results_with_field(self, *,
-                                              query_term: str,
-                                              field_name: str,
-                                              field_value: str,
-                                              page_index: int = 0,
-                                              index: str = '') -> SearchResult:
-        pass
-
     @abstractmethod
     def fetch_table_search_results(self, *,
                                    query_term: str,
                                    page_index: int = 0,
-                                   index: str = '') -> SearchResult:
+                                   index: str = '') -> SearchTableResult:
         pass
 
     @abstractmethod
@@ -52,16 +45,17 @@ class BaseProxy(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def fetch_table_search_results_with_filter(self, *,
-                                               query_term: str,
-                                               search_request: dict,
-                                               page_index: int = 0,
-                                               index: str = '') -> SearchResult:
+    def fetch_search_results_with_filter(self, *,
+                                         query_term: str,
+                                         search_request: dict,
+                                         page_index: int = 0,
+                                         index: str = '') -> Union[SearchTableResult,
+                                                                   SearchDashboardResult]:
         pass
 
     @abstractmethod
     def fetch_dashboard_search_results(self, *,
                                        query_term: str,
                                        page_index: int = 0,
-                                       index: str = '') -> SearchResult:
+                                       index: str = '') -> SearchDashboardResult:
         pass
